@@ -7,6 +7,10 @@ from copy import deepcopy
 import json
 import os
 import PIL
+import re
+import requests
+import urllib
+from io import BytesIO
 
 class ModelifyInputs:
     def __init__(self):
@@ -69,18 +73,32 @@ class Image(ModelifyInputs):
         return [{"width": self.width, "height": self.height, "channel": self.channel,
                  "channel_format": self.channel_format}]
 
-    def read_image(self, image_url: str, format="RGB"):
+    def is_url(self, url):
+        regex = re.compile(
+            r'^(?:http|ftp)s?://' 
+            r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
+            r'localhost|' 
+            r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' 
+            r'(?::\d+)?' 
+            r'(?:/?|[/?]\S+)$', re.IGNORECASE)
+        return re.match(regex, url) is not None
+
+    def read_image(self, image_content, format="RGB"):
         try:
-            image = PIL.Image.open(image_url).convert(format)
+            image = PIL.Image.open(image_content).convert(format)
             return image
         except Exception as ex:
-            print(str(ex), has_pii=True)
+            raise Exception("Error reading image: {}".format(ex))
 
     def get_input_for_model(self, preprocess=False, image_source=None):
         if image_source is None:
             if self.sample is None:
                 raise Exception("No sample image provided")
-            image_source = os.path.join(os.getcwd(), self.sample)
+            if self.is_url(self.sample):
+                response = requests.get(self.sample)
+                image_source = BytesIO(response.content)
+            else:
+                image_source = os.path.join(os.getcwd(), self.sample)
         if self.channel == 1 or self.channel is None:
             img = self.read_image(image_source, format="L")
         else:
